@@ -1,11 +1,4 @@
 
-
-
-# climate.data: quantiles of annual climate, as returned by fetchOSD(..., extended=TRUE)
-# s: series name
-# IQR.width: width of IQR band
-# ...: further arguments to segplot
-
 #' @title Annual Climate Summaries for Soil Series Data
 #' 
 #' @description Annual climate summaries for soil series, based on `latticeExtra::segplot`, based on 5th, 25th, 50th, 75th, and 95th percentiles. Input data should be from `soilDB::fetchOSD`.
@@ -31,77 +24,18 @@
 #' 
 #' @export
 #'
-#' @examples
-#' 
-#' \donttest{
-#' if(requireNamespace("curl") &
-#' curl::has_internet() &
-#'   require(soilDB) & 
-#'   require(aqp) & 
-#'   require(latticeExtra)
-#' ) {
-#'   
-#'   # soil series of interest
-#'   soil <- 'ARBUCKLE'
-#'   
-#'   # get competing series
-#'   sdata <- fetchOSD(soil, extended = TRUE)
-#'   
-#'   # get competing series' data
-#'   sdata.competing <- fetchOSD(c(soil, sdata$competing$competing))
-#'   
-#'   # only use established series
-#'   idx <- which(sdata.competing$series_status == 'established')
-#'   
-#'   # subset as needed
-#'   if(length(idx) < length(sdata.competing)) {
-#'     sdata.competing <- sdata.competing[idx, ]
-#'     
-#'   }
-#'   
-#'   # now get the extended data
-#'   sdata.competing.full <- fetchOSD(site(sdata.competing)$id, extended = TRUE)
-#'   
-#'   # extract SPC
-#'   spc <- sdata.competing.full$SPC
-#'   
-#'   # full set of series names
-#'   s.names <- unique(site(spc)$id)
-#'   
-#'   # todo: probably better ways to do this...
-#'   # note: need to load lattice for this to work
-#'   trellis.par.set(plot.line=list(col='RoyalBlue'))
-#'   
-#'   # control center symbol and size here
-#'   res <- vizAnnualClimate(
-#'   sdata.competing.full$climate.annual, 
-#'   s = soil, 
-#'   IQR.cex = 1.1, 
-#'   cex = 1.1, 
-#'   pch = 18
-#'   )
-#'   
-#'   # plot figure
-#'   print(res$fig)
-#'   
-#'   # check clustering
-#'   str(res$clust)
-#'   
-#'   # do something with clustering
-#'   op <- par(no.readonly = TRUE)
-#'   
-#'   par(mar=c(0,0,1,1))
-#'   plotProfileDendrogram(spc, clust = res$clust, scaling.factor = 0.075, width = 0.2, y.offset = 0.5)
-#'   mtext('sorted by annual climate summaries', side = 3, at = 0.5, adj = 0, line = -1.5, font=3)
-#'   
-#'   par(op)
-#'   
-#' }
-#' 
-#' }
 #' 
 vizAnnualClimate <- function(climate.data, IQR.cex = 1, s = NULL, s.col = 'firebrick', ...) {
   
+  # sanity checks on input
+  if(!inherits(climate.data, 'data.frame')) {
+    stop('x must be a data.frame', call. = FALSE)
+  }
+  
+  if(nrow(climate.data) < 1) {
+    stop('x must contain at least 1 row of data', call. = FALSE)
+  }
+  
   # check for required packages
   if(!requireNamespace('latticeExtra', quietly=TRUE))
     stop('please install the `latticeExtra` package', call.=FALSE)
